Metrics
------------------------

.. automodule:: flax.nnx.metrics
.. currentmodule:: flax.nnx.metrics

.. autoclass:: Metric
   :members:
.. autoclass:: Average
   :members:
.. autoclass:: Accuracy
   :members:
.. autoclass:: MultiMetric
   :members:

